@@ -17,9 +17,9 @@ def npn_W1L1(
     contact_size: Float2 = (0.17, 0.17),
     contact_spacing: Float2 = (0.17, 0.17),
     contact_layer: LayerSpec = (66, 44),
-    contact_enclosure: float = (0.06, 0.06),
+    contact_enclosure: Float2 = (0.06, 0.06),
     pwell_layer: LayerSpec = (64, 13),
-    dnwell_enclosure: float = (0.4, 0.4),
+    dnwell_enclosure: Float2 = (0.4, 0.4),
     dnwell_layer: LayerSpec = (64, 18),
     sdm_enclosure: Float2 = (0.125, 0.125),
     nsdm_layer: LayerSpec = (93, 44),
@@ -34,7 +34,6 @@ def npn_W1L1(
     mcon_enclosure: Float2 = (0.09, 0.09),
     m1_layer: LayerSpec = (68, 20),
 ) -> gf.Component:
-
     """Return npn_W1L1.
 
     npn device with emitter size 1u*1u
@@ -46,8 +45,6 @@ def npn_W1L1(
 
       c = sky130.pcells.npn_W1L1(np_spacing=1, B_width=0.8, C_width=0.8, E_length=2)
       c.plot()
-
-
     """
     c = gf.Component()
 
@@ -234,7 +231,7 @@ def npn_W1L1(
             size=(
                 E_width
                 + 2 * np_spacing
-                + ((B_width - nc * contact_size[0] - (nc - 1) * contact_spacing[0]))
+                + (B_width - nc * contact_size[0] - (nc - 1) * contact_spacing[0])
                 - 2 * i * mcon_enclosure[0]
                 - 2 * (1 - i) * li_enclosure,
                 E_length
@@ -252,13 +249,13 @@ def npn_W1L1(
                 E_width
                 + 2 * np_spacing
                 + 2 * B_width
-                - ((B_width - nc * contact_size[0] - (nc - 1) * contact_spacing[0]))
+                - (B_width - nc * contact_size[0] - (nc - 1) * contact_spacing[0])
                 + 2 * i * mcon_enclosure[0]
                 + 2 * (1 - i) * li_enclosure,
                 E_length
                 + 2 * np_spacing
                 + 2 * B_width
-                - ((B_width - nc * contact_size[1] - (nc - 1) * contact_spacing[1]))
+                - (B_width - nc * contact_size[1] - (nc - 1) * contact_spacing[1])
                 + 2 * i * mcon_enclosure[1]
                 + 2 * (1 - i) * li_enclosure,
             ),
