@@ -15,12 +15,12 @@ def pmos_5v(
     contact_size: Float2 = (0.17, 0.17),
     contact_spacing: Float2 = (0.17, 0.17),
     contact_layer: LayerSpec = (66, 44),
-    contact_enclosure: float = (0.06, 0.06),
+    contact_enclosure: Float2 = (0.06, 0.06),
     diff_spacing: float = 0.37,
     diff_enclosure: Float2 = (0.33, 0.33),
     diffn_layer: LayerSpec = (65, 44),
     nwell_layer: LayerSpec = (64, 22),
-    dnwell_enclosure: float = (0.4, 0.4),
+    dnwell_enclosure: Float2 = (0.4, 0.4),
     dnwell_layer: LayerSpec = (64, 18),
     nf: int = 1,
     sdm_enclosure: Float2 = (0.125, 0.125),
