@@ -17,7 +17,7 @@ def pnp(
     contact_size: Float2 = (0.17, 0.17),
     contact_spacing: Float2 = (0.17, 0.17),
     contact_layer: LayerSpec = (66, 44),
-    contact_enclosure: float = (0.06, 0.06),
+    contact_enclosure: Float2 = (0.06, 0.06),
     nwell_layer: LayerSpec = (64, 20),
     sdm_enclosure: Float2 = (0.125, 0.125),
     nsdm_layer: LayerSpec = (93, 44),
@@ -32,7 +32,6 @@ def pnp(
     mcon_enclosure: Float2 = (0.09, 0.09),
     m1_layer: LayerSpec = (68, 20),
 ) -> gf.Component:
-
     """Return pnp.
 
     .. plot::
@@ -229,7 +228,7 @@ def pnp(
             size=(
                 E_width
                 + 2 * np_spacing
-                + ((B_width - nc_v * contact_size[0] - (nc_v - 1) * contact_spacing[0]))
+                + (B_width - nc_v * contact_size[0] - (nc_v - 1) * contact_spacing[0])
                 - 2 * i * mcon_enclosure[0]
                 - 2 * (1 - i) * li_enclosure,
                 E_length
@@ -247,13 +246,13 @@ def pnp(
                 E_width
                 + 2 * np_spacing
                 + 2 * B_width
-                - ((B_width - nc_v * contact_size[0] - (nc_v - 1) * contact_spacing[0]))
+                - (B_width - nc_v * contact_size[0] - (nc_v - 1) * contact_spacing[0])
                 + 2 * i * mcon_enclosure[0]
                 + 2 * (1 - i) * li_enclosure,
                 E_length
                 + 2 * np_spacing
                 + 2 * B_width
-                - ((B_width - nr_h * contact_size[1] - (nr_h - 1) * contact_spacing[1]))
+                - (B_width - nr_h * contact_size[1] - (nr_h - 1) * contact_spacing[1])
                 + 2 * i * mcon_enclosure[1]
                 + 2 * (1 - i) * li_enclosure,
             ),
